==> wiki3_5_5.zip: wiki3_5_5/plugin/format/FormatSelector.pm <==
###############################################################################
#
# <p>ԽեޥåȤ򤹤뤿Υץ饰Ǥ</p>
#
###############################################################################
package plugin::format::FormatSelector;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self  = {};
	return bless $self,$class;
}

#==============================================================================
# Խե˽񼰤򤹤뤿ΥܥܥåϤޤ
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $page   = $cgi->param('page');
	my $format = $wiki->get_edit_format();
	my @list   = $wiki->get_format_names();
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"CHANGE_FORMAT\">\n".
	          "  <input type=\"hidden\" name=\"query\" value=\"".$ENV{'QUERY_STRING'}."\">\n".
	          "  <select name=\"format\">\n";

	foreach my $value (@list){
		$buf .= "    <option value=\"".&Util::escapeHTML($value)."\"";
		if($value eq $format){
			$buf .= " selected";
		}
		$buf .= ">".&Util::escapeHTML($value)."</option>\n";
	}
	
	$buf .= "  </select>\n".
	        "  <input type=\"submit\" value=\"ѹ\">\n".
	        "</form>\n";
	
	return $buf;
}

#==============================================================================
# ѹνޤ
#==============================================================================
sub do_action {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $page   = $cgi->param('page');
	my $format = $cgi->param('format');
	
	if($format eq ""){
		$format = "FSWiki";
	}
	
	my $cookie = $cgi->cookie(-name=>'edit_format',-value=>$format,-expires=>'+1M');
	print "Set-Cookie: ",$cookie->as_string,"\n";
	
	my $url = $wiki->config('script_name');
	if($cgi->param('query') ne ''){
		$url .= "?".$cgi->param('query');
	}
	
	$wiki->redirectURL($url);
}

1;

==> wiki3_5_6dev2.zip: wiki3_5_6dev2/plugin/format/FormatSelector.pm <==
###############################################################################
#
# <p>ԽեޥåȤ򤹤뤿Υץ饰Ǥ</p>
#
###############################################################################
package plugin::format::FormatSelector;
use strict;
#==============================================================================
# 󥹥ȥ饯
#==============================================================================
sub new {
	my $class = shift;
	my $self  = {};
	return bless $self,$class;
}

#==============================================================================
# Խե˽񼰤򤹤뤿ΥܥܥåϤޤ
#==============================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $page   = $cgi->param('page');
	my $format = $wiki->get_edit_format();
	my @list   = $wiki->get_format_names();
	
	my $buf = "<form action=\"".$wiki->config('script_name')."\" method=\"POST\">\n".
	          "  <input type=\"hidden\" name=\"action\" value=\"CHANGE_FORMAT\">\n".
	          "  <input type=\"hidden\" name=\"query\" value=\"".$ENV{'QUERY_STRING'}."\">\n".
	          "  <select name=\"format\">\n";

	foreach my $value (@list){
		$buf .= "    <option value=\"".&Util::escapeHTML($value)."\"";
		if($value eq $format){
			$buf .= " selected";
		}
		$buf .= ">".&Util::escapeHTML($value)."</option>\n";
	}
	
	$buf .= "  </select>\n".
	        "  <input type=\"submit\" value=\"ѹ\">\n".
	        "</form>\n";
	
	return $buf;
}

#==============================================================================
# ѹνޤ
#==============================================================================
sub do_action {
	my $self   = shift;
	my $wiki   = shift;
	my $cgi    = $wiki->get_CGI();
	my $page   = $cgi->param('page');
	my $format = $cgi->param('format');
	
	if($format eq ""){
		$format = "FSWiki";
	}
	
	my $path   = $ENV{SCRIPT_NAME};
	my $cookie = $cgi->cookie(-name=>'edit_format',-value=>$format,-expires=>'+1M',-path=>$path);
	print "Set-Cookie: ",$cookie->as_string,"\n";
	
	my $url = $wiki->config('script_name');
	if($cgi->param('query') ne ''){
		$url .= "?".$cgi->param('query');
	}
	
	$wiki->redirectURL($url);
}

1;
